## 国际化

VueCesium 组件内部默认使用中文，若希望使用其他语言，则需要进行多语言设置。以中文为例，在 main.js 中，如果是完整引入 VueCesium：

```javascript
import { createApp } from 'vue'
import VueCesium from 'vue-cesium'
import locale from 'vue-cesium/lib/locale/lang/en-us'

createApp(App).use(VueCesium, { locale })
```

如果是通过 **es modules** 按需引入 VueCesium:

```typescript
import { createApp } from 'vue'
import { Viewer, locale } from 'vue-cesium'
import lang from 'vue-cesium/locale/lang/en-us'

locale(lang)
createApp(App).component(Viewer.name, Viewer)
```

如果是通过 [babel-plugin-component](#/zh-CN/component/quickstart#an-xu-yin-ru) 插件按需引入 VueCesium:

```typescript
import { createApp } from 'vue'
import { Viewer } from 'vue-cesium'
import lang from 'vue-cesium/lib/locale/lang/zh-Hans'
import locale from 'vue-cesium/lib/locale'

// 设置语言
locale.use(lang)

// 引入组件
createApp(App).component(Viewer.name, Viewer)
```


如果使用其它语言，默认情况下英文语言包依旧是被引入的，可以使用 webpack 的 NormalModuleReplacementPlugin 替换默认语言包。

**webpack.config.js**

```typescript
{
  plugins: [
    new webpack.NormalModuleReplacementPlugin(
      /vue-cesium[\/\\]lib[\/\\]locale[\/\\]lang[\/\\]zh-Hans/,
      'vue-cesium/lib/locale/lang/en-us',
    ),
  ]
}
```


### 兼容 `vue-i18n@9.x`

如果需要查看 [VueI18n的文档](https://vue-i18n-next.intlify.dev/guide/#html), 请点击这个链接去查看

```typescript
import { createApp } from 'vue'
import { createI18n } from 'vue-i18n'
import VueCesium from 'vue-cesium'
import enLocale from 'vue-cesium/lib/locale/lang/en-us'
import zhLocale from 'vue-cesium/lib/locale/lang/zh-Hans'
import App from './App.vue'

const messages = {
  [enLocale.name]: {
    // vc 这个属性很关键，一定要保证有这个属性，
    vc: enLocale.vc,
    // 定义您自己的字典，但是请不要和 `vc` 重复，这样会导致 VueCesium 内部组件的翻译失效.
    message: {
      hello: 'hello world',
    },
  },
  [zhLocale.name]: {
    vc: zhLocale.vc,
    // 定义您自己的字典，但是请不要和 `vc` 重复，这样会导致 VueCesium 内部组件的翻译失效.
    message: {
      hello: '你好，世界',
    },
  },
  testLocale: {
    vc: {},
    // 没有定义 message 字段，会 fallback 回到 en 去, fallbackLocale 的定义在下方 👇
  },
}

const i18n = createI18n({
  locale: zhLocale.name,
  fallbackLocale: enLocale.name,
  messages,
})

const app = createApp(App)

app.use(VueCesium, {
  i18n: i18n.global.t,
})

// 要记得使用这个插件.
app.use(i18n)
```

目前 VueCesium 内置了以下语言：

<ul class="language-list">
  <li>简体中文（zh-hans）</li>
  <li>英文（en-us）</li>
</ul>

如果你需要使用其他的语言，欢迎贡献 PR：只需在 [这里](https://github.com/zouyaoji/vue-cesium/tree/dev/packages/locale/lang) 添加一个语言配置文件即可。
